"use strict";

const e = React.createElement;

// Use useRef to set up canvas.
// Relevant info:
// https://dev.to/vnglst/using-react-hooks-with-canvas-gn8
function MainContainer() {
  const [selected, setSelected] = React.useState("frog");
  const selectStamp = (stampId) => {
    return () => {
      let stamp = stamps[stampId];
      console.log(stamp);
      if (!!stamp.audioDescription) {
        console.log(stamp.audioDescription);
        let audio = new Audio(stamp.audioDescription);
        audio.play();
      }
      setSelected(stampId);
    };
  };

  const canvasRef = React.useRef(null);
  const handleCanvasClick = (event) => {
    const canvas = canvasRef.current;
    const ctx = canvas.getContext('2d');
    let stamp = stamps[selected];
    if (!!stamp.sound) {
      let audio = new Audio(stamp.sound);
      audio.play();
    }
    const image = document.getElementById(stamp.image);
    ctx.drawImage(image, event.clientX - image.width / 2, event.clientY - image.height / 2);
  };

  return (<div id="container">
    <canvas id="drawing" onClick={handleCanvasClick} ref={canvasRef} width={window.innerWidth} height={window.innerHeight}></canvas>
    <div id="description_container">
      {stamps[selected].description || ""}
    </div>
    <div className="stamps-container">
      {Object.keys(stamps).map((stampId) => {
        let stamp = stamps[stampId];
        let isSelected = stampId === selected;
        let stampClassName = isSelected ? "stamp stamp-selected" : "stamp";
        return (<div key={stamp.image} className={stampClassName} onClick={selectStamp(stampId)}>
          <img className="stamp-image" id={stamp.image} src={stamp.image}></img>
        </div>);
      })}
    </div>
  </div>);
}

// Initialize React.
const domContainer = document.querySelector("#react_container");
const root = ReactDOM.createRoot(domContainer);
root.render(e(MainContainer));
